summaryrefslogtreecommitdiffstats
path: root/tdeui/kaboutapplication.h
diff options
context:
space:
mode:
authorTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
committerTimothy Pearson <kb9vqf@pearsoncomputing.net>2013-01-22 20:20:05 -0600
commitb19ddece21e102b8e4b292037ca7578f60b128fe (patch)
tree6572ca25aba80849cdfa7578bbbc9121d23afbc3 /tdeui/kaboutapplication.h
parente729c6d549f12e27b358a1dad04ff254c033ac71 (diff)
downloadtdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.tar.gz
tdelibs-b19ddece21e102b8e4b292037ca7578f60b128fe.zip
Rename KInstance and KAboutData to avoid conflicts with KDE4
Diffstat (limited to 'tdeui/kaboutapplication.h')
-rw-r--r--tdeui/kaboutapplication.h12
1 files changed, 6 insertions, 6 deletions
diff --git a/tdeui/kaboutapplication.h b/tdeui/kaboutapplication.h
index 58145aa45..7fe088d02 100644
--- a/tdeui/kaboutapplication.h
+++ b/tdeui/kaboutapplication.h
@@ -31,7 +31,7 @@
*
* This class provides the standard "About Application" dialog box
* that is used by KHelpMenu. It uses the information of the global
* KAboutData that is specified at the start of your program in
* main(). Normally you should not use this class directly but rather
* the KHelpMenu class or even better just subclass your toplevel
* window from KMainWindow. If you do the latter, the help menu and
@@ -61,12 +61,12 @@ class TDEUI_EXPORT KAboutApplication : public KAboutDialog
/**
* Constructor. Mostly does the same stuff as the previous constructor, except
* that it can take a custom KAboutData object instead of the one specified
* in your main() function. This is especially useful for applications
* which are implemented as (dynamically loaded) libraries, e.g. panel
* applets.
*
* @param aboutData A pointer to a KAboutData object which data
* will be used for filling the dialog.
* @param parent The parent of the dialog box. You should use the
* toplevel window so that the dialog becomes centered.
@@ -76,17 +76,17 @@ class TDEUI_EXPORT KAboutApplication : public KAboutDialog
* made visible using TQWidget::show(). Otherwise it will be
* modal and must be made visible using TQWidget::exec().
*/
- KAboutApplication( const KAboutData *aboutData, TQWidget *parent=0, const char *name=0, bool modal=true );
+ KAboutApplication( const TDEAboutData *aboutData, TQWidget *parent=0, const char *name=0, bool modal=true );
/*
FIXME: The two constructors should be replaced with the following after the lib freeze:
- KAboutApplication( const KAboutData *aboutData=0, TQWidget *parent=0, const char *name=0, bool modal=true );
+ KAboutApplication( const TDEAboutData *aboutData=0, TQWidget *parent=0, const char *name=0, bool modal=true );
This will make buildDialog() obsolete as well (Frerich).
*/
protected:
- void buildDialog( const KAboutData *aboutData );
+ void buildDialog( const TDEAboutData *aboutData );
};
@@ -31,7 +31,7 @@
* This class provides the standard "About Application" dialog box
* that is used by KHelpMenu. It uses the information of the global
- * KAboutData that is specified at the start of your program in
+ * TDEAboutData that is specified at the start of your program in
* main(). Normally you should not use this class directly but rather
* the KHelpMenu class or even better just subclass your toplevel
@@ -61,12 +61,12 @@ class TDEUI_EXPORT KAboutApplication : public KAboutDialog
/**
* Constructor. Mostly does the same stuff as the previous constructor, except
- * that it can take a custom KAboutData object instead of the one specified
+ * that it can take a custom TDEAboutData object instead of the one specified
* in your main() function. This is especially useful for applications
* which are implemented as (dynamically loaded) libraries, e.g. panel
@@ -61,12 +61,12 @@ class TDEUI_EXPORT KAboutApplication : public KAboutDialog
* applets.
*
- * @param aboutData A pointer to a KAboutData object which data
+ * @param aboutData A pointer to a TDEAboutData object which data
* will be used for filling the dialog.
* @param parent The parent of the dialog box. You should use the